/*
 *  JBoss, Home of Professional Open Source
 *  Copyright 2010 Red Hat, Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package javax.ejb;

/**
 * <P>The EJBMetaData interface allows a client to obtain the enterprise
 * Bean's meta-data information. </P>
 * 
 * <P>The meta-data is intended for development tools used for building
 * applications that use deployed enterprise Beans, and for clients using
 * a scripting language to access the enterprise Bean. </P>
 * 
 * <P>Note that the EJBMetaData is not a remote interface. The class that
 * implements this interface (this class is typically generated by container
 * tools) must be serializable, and must be a valid RMI/IDL value type. </P>
 */
public interface EJBMetaData {

  /**
   * Obtains the home interface of the enterprise Bean.
   *
   * @return The home interface of the enterprise Bean.
   */
  public EJBHome getEJBHome();

  /**
   * Obtains the Class object for the enterprise Bean's home interface.
   *
   * @return The class object for the enterprise Bean's home interface.
   */
  public Class getHomeInterfaceClass();

   /**
    * Obtains the Class object for the enterprise Bean's remote interface.
    *
    * @return The class object for the enterprise Bean's remote interface.
    */
   public Class getRemoteInterfaceClass();

  /**
   * Obtains the Class object for the enterprise Bean's primary key class.
   *
   * @return The class object for the enterprise Bean's primary key class.
   */
  public Class getPrimaryKeyClass();

  /**
   * Tests if the type of the enterprise Bean is "session".
   *
   * @return True if the type of the enterprise Bean is session bean.
   */
  public boolean isSession();

  /**
   * Tests if the type of the enterprise Bean is "stateless session".
   *
   * @return True if the type of the enterprise Bean is stateless session.
   */
  public boolean isStatelessSession();
}
